## Using this Adapter

The `adapter.js` file contains the calls the adapter makes available to the rest of the Itential Platform. The API detailed for these calls should be available through JSDOC. The following is a brief summary of the calls.

### Generic Adapter Calls

These are adapter methods that Itential Platform or you might use. There are some other methods not shown here that might be used for internal adapter functionality.

<table border="1" class="bordered-table">
  <tr>
    <th bgcolor="lightgrey" style="padding:15px"><span style="font-size:12.0pt">Method Signature</span></th>
    <th bgcolor="lightgrey" style="padding:15px"><span style="font-size:12.0pt">Description</span></th>
    <th bgcolor="lightgrey" style="padding:15px"><span style="font-size:12.0pt">Workflow?</span></th>
  </tr>
  <tr>
    <td style="padding:15px">connect()</td>
    <td style="padding:15px">This call is run when the Adapter is first loaded by the Itential Platform. It validates the properties have been provided correctly.</td>
    <td style="padding:15px">No</td>
  </tr>
  <tr>
    <td style="padding:15px">healthCheck(callback)</td>
    <td style="padding:15px">This call ensures that the adapter can communicate with Adapter for Redis Cloud. The actual call that is used is defined in the adapter properties and .system entities action.json file.</td>
    <td style="padding:15px">No</td>
  </tr>
  <tr>
    <td style="padding:15px">refreshProperties(properties)</td>
    <td style="padding:15px">This call provides the adapter the ability to accept property changes without having to restart the adapter.</td>
    <td style="padding:15px">No</td>
  </tr>
  <tr>
    <td style="padding:15px">encryptProperty(property, technique, callback)</td>
    <td style="padding:15px">This call will take the provided property and technique, and return the property encrypted with the technique. This allows the property to be used in the adapterProps section for the credential password so that the password does not have to be in clear text. The adapter will decrypt the property as needed for communications with Adapter for Redis Cloud.</td>
    <td style="padding:15px">No</td>
  </tr>
  <tr>
    <td style="padding:15px">iapUpdateAdapterConfiguration(configFile, changes, entity, type, action, callback)</td>
    <td style="padding:15px">This call provides the ability to update the adapter configuration from Itential Platform - includes actions, schema, mockdata and other configurations.</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">iapSuspendAdapter(mode, callback)</td>
    <td style="padding:15px">This call provides the ability to suspend the adapter and either have requests rejected or put into a queue to be processed after the adapter is resumed.</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">iapUnsuspendAdapter(callback)</td>
    <td style="padding:15px">This call provides the ability to resume a suspended adapter. Any requests in queue will be processed before new requests.</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">iapGetAdapterQueue(callback)</td>
    <td style="padding:15px">This call will return the requests that are waiting in the queue if throttling is enabled.</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">iapFindAdapterPath(apiPath, callback)</td>
    <td style="padding:15px">This call provides the ability to see if a particular API path is supported by the adapter.</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">iapTroubleshootAdapter(props, adapter, callback)</td>
    <td style="padding:15px">This call can be used to check on the performance of the adapter - it checks connectivity, healthcheck and basic get calls.</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">iapRunAdapterHealthcheck(adapter, callback)</td>
    <td style="padding:15px">This call will return the results of a healthcheck.</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">iapRunAdapterConnectivity(callback)</td>
    <td style="padding:15px">This call will return the results of a connectivity check.</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">iapRunAdapterBasicGet(maxCalls, callback)</td>
    <td style="padding:15px">This call will return the results of running basic get API calls. By default 5 get calls without parameters will be run. You can ask for more or less by setting maxCalls.</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">iapMoveAdapterEntitiesToDB(callback)</td>
    <td style="padding:15px">This call will push the adapter configuration from the entities directory into the Adapter or Itential Platform Database.</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">iapDeactivateTasks(tasks, callback)</td>
    <td style="padding:15px">This call provides the ability to remove tasks from the adapter.</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">iapActivateTasks(tasks, callback)</td>
    <td style="padding:15px">This call provides the ability to add deactivated tasks back into the adapter.</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">iapExpandedGenericAdapterRequest(metadata, uriPath, restMethod, pathVars, queryData, requestBody, addlHeaders, callback)</td>
    <td style="padding:15px">This is an expanded Generic Call. The metadata object allows us to provide many new capabilities within the generic request.</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">genericAdapterRequest(uriPath, restMethod, queryData, requestBody, addlHeaders, callback)</td>
    <td style="padding:15px">This call allows you to provide the path to have the adapter call. It is an easy way to incorporate paths that have not been built into the adapter yet.</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">genericAdapterRequestNoBasePath(uriPath, restMethod, queryData, requestBody, addlHeaders, callback)</td>
    <td style="padding:15px">This call is the same as the genericAdapterRequest only it does not add a base_path or version to the call.</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">iapRunAdapterLint(callback)</td>
    <td style="padding:15px">Runs lint on the addapter and provides the information back.</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">iapRunAdapterTests(callback)</td>
    <td style="padding:15px">Runs baseunit and unit tests on the adapter and provides the information back.</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">iapGetAdapterInventory(callback)</td>
    <td style="padding:15px">This call provides some inventory related information about the adapter.</td>
    <td style="padding:15px">Yes</td>
  </tr>
</table>
<br>
  
### Adapter Cache Calls

These are adapter methods that are used for adapter caching. If configured, the adapter will cache based on the interval provided. However, you can force a population of the cache manually as well.

<table border="1" class="bordered-table">
  <tr>
    <th bgcolor="lightgrey" style="padding:15px"><span style="font-size:12.0pt">Method Signature</span></th>
    <th bgcolor="lightgrey" style="padding:15px"><span style="font-size:12.0pt">Description</span></th>
    <th bgcolor="lightgrey" style="padding:15px"><span style="font-size:12.0pt">Workflow?</span></th>
  </tr>
  <tr>
    <td style="padding:15px">iapPopulateEntityCache(entityTypes, callback)</td>
    <td style="padding:15px">This call populates the adapter cache.</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">iapRetrieveEntitiesCache(entityType, options, callback)</td>
    <td style="padding:15px">This call retrieves the specific items from the adapter cache.</td>
    <td style="padding:15px">Yes</td>
  </tr>
</table>
<br>
  
### Adapter Broker Calls

These are adapter methods that are used to integrate to Itential Platform Brokers. This adapter currently supports the following broker calls.

<table border="1" class="bordered-table">
  <tr>
    <th bgcolor="lightgrey" style="padding:15px"><span style="font-size:12.0pt">Method Signature</span></th>
    <th bgcolor="lightgrey" style="padding:15px"><span style="font-size:12.0pt">Description</span></th>
    <th bgcolor="lightgrey" style="padding:15px"><span style="font-size:12.0pt">Workflow?</span></th>
  </tr>
  <tr>
    <td style="padding:15px">hasEntities(entityType, entityList, callback)</td>
    <td style="padding:15px">This call is utilized by the Itential Platform Device Broker to determine if the adapter has a specific entity and item of the entity.</td>
    <td style="padding:15px">No</td>
  </tr>
  <tr>
    <td style="padding:15px">getDevice(deviceName, callback)</td>
    <td style="padding:15px">This call returns the details of the requested device.</td>
    <td style="padding:15px">No</td>
  </tr>
  <tr>
    <td style="padding:15px">getDevicesFiltered(options, callback)</td>
    <td style="padding:15px">This call returns the list of devices that match the criteria provided in the options filter.</td>
    <td style="padding:15px">No</td>
  </tr>
  <tr>
    <td style="padding:15px">isAlive(deviceName, callback)</td>
    <td style="padding:15px">This call returns whether the device status is active</td>
    <td style="padding:15px">No</td>
  </tr>
  <tr>
    <td style="padding:15px">getConfig(deviceName, format, callback)</td>
    <td style="padding:15px">This call returns the configuration for the selected device.</td>
    <td style="padding:15px">No</td>
  </tr>
  <tr>
    <td style="padding:15px">iapGetDeviceCount(callback)</td>
    <td style="padding:15px">This call returns the count of devices.</td>
    <td style="padding:15px">No</td>
  </tr>
</table>
<br>


### Specific Adapter Calls

Specific adapter calls are built based on the API of the Redis_cloud. The Adapter Builder creates the proper method comments for generating JS-DOC for the adapter. This is the best way to get information on the calls.

<table border="1" class="bordered-table">
  <tr>
    <th bgcolor="lightgrey" style="padding:15px"><span style="font-size:12.0pt">Method Signature</span></th>
    <th bgcolor="lightgrey" style="padding:15px"><span style="font-size:12.0pt">Description</span></th>
    <th bgcolor="lightgrey" style="padding:15px"><span style="font-size:12.0pt">Path</span></th>
    <th bgcolor="lightgrey" style="padding:15px"><span style="font-size:12.0pt">Workflow?</span></th>
  </tr>
  <tr>
    <td style="padding:15px">getUserById(userId, callback)</td>
    <td style="padding:15px">Get user by id</td>
    <td style="padding:15px">{base_path}/{version}/users/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">updateUser(userId, body, callback)</td>
    <td style="padding:15px">Update user</td>
    <td style="padding:15px">{base_path}/{version}/users/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteUserById(userId, callback)</td>
    <td style="padding:15px">Delete user</td>
    <td style="padding:15px">{base_path}/{version}/users/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getAllUsers(callback)</td>
    <td style="padding:15px">Get users</td>
    <td style="padding:15px">{base_path}/{version}/users?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getSubscriptionById(subscriptionId, callback)</td>
    <td style="padding:15px">Get subscription by id</td>
    <td style="padding:15px">{base_path}/{version}/subscriptions/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">updateSubscription(subscriptionId, body, callback)</td>
    <td style="padding:15px">Update subscription</td>
    <td style="padding:15px">{base_path}/{version}/subscriptions/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteSubscriptionById(subscriptionId, callback)</td>
    <td style="padding:15px">Delete subscription</td>
    <td style="padding:15px">{base_path}/{version}/subscriptions/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">updateActiveActiveVpcPeering(subscriptionId, peeringId, body, callback)</td>
    <td style="padding:15px">Update an active-active subscription VPC peering</td>
    <td style="padding:15px">{base_path}/{version}/subscriptions/{pathv1}/regions/peerings/{pathv2}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteActiveActiveVpcPeering(subscriptionId, peeringId, callback)</td>
    <td style="padding:15px">Delete an active-active subscription VPC peering</td>
    <td style="padding:15px">{base_path}/{version}/subscriptions/{pathv1}/regions/peerings/{pathv2}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">updateVpcPeering(subscriptionId, peeringId, body, callback)</td>
    <td style="padding:15px">Update subscription peering</td>
    <td style="padding:15px">{base_path}/{version}/subscriptions/{pathv1}/peerings/{pathv2}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteVpcPeering(subscriptionId, peeringId, callback)</td>
    <td style="padding:15px">Delete subscription peering</td>
    <td style="padding:15px">{base_path}/{version}/subscriptions/{pathv1}/peerings/{pathv2}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getCidrWhiteList(subscriptionId, callback)</td>
    <td style="padding:15px">Get subscription CIDR</td>
    <td style="padding:15px">{base_path}/{version}/subscriptions/{pathv1}/cidr?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">updateSubscriptionCidrWhiteList(subscriptionId, body, callback)</td>
    <td style="padding:15px">Update subscription CIDR</td>
    <td style="padding:15px">{base_path}/{version}/subscriptions/{pathv1}/cidr?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getAllSubscriptions(callback)</td>
    <td style="padding:15px">Get subscriptions</td>
    <td style="padding:15px">{base_path}/{version}/subscriptions?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">createSubscription(body, callback)</td>
    <td style="padding:15px">Create subscription</td>
    <td style="padding:15px">{base_path}/{version}/subscriptions?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getRegionsFromActiveActiveSubscription(subscriptionId, callback)</td>
    <td style="padding:15px">Get active-active subscription regions</td>
    <td style="padding:15px">{base_path}/{version}/subscriptions/{pathv1}/regions?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">addNewRegionToActiveActiveSubscription(subscriptionId, body, callback)</td>
    <td style="padding:15px">Create active-active subscription region</td>
    <td style="padding:15px">{base_path}/{version}/subscriptions/{pathv1}/regions?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteRegionsFromActiveActiveSubscription(subscriptionId, body, callback)</td>
    <td style="padding:15px">Delete active-active subscription regions</td>
    <td style="padding:15px">{base_path}/{version}/subscriptions/{pathv1}/regions?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getActiveActiveVpcPeerings(subscriptionId, callback)</td>
    <td style="padding:15px">Get an active-active subscription VPC peering</td>
    <td style="padding:15px">{base_path}/{version}/subscriptions/{pathv1}/regions/peerings?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">createActiveActiveVpcPeering(subscriptionId, body, callback)</td>
    <td style="padding:15px">Create an active-active subscription VPC peering</td>
    <td style="padding:15px">{base_path}/{version}/subscriptions/{pathv1}/regions/peerings?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getVpcPeering(subscriptionId, callback)</td>
    <td style="padding:15px">Get Subscription peering</td>
    <td style="padding:15px">{base_path}/{version}/subscriptions/{pathv1}/peerings?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">createVpcPeering(subscriptionId, body, callback)</td>
    <td style="padding:15px">Create subscription peering</td>
    <td style="padding:15px">{base_path}/{version}/subscriptions/{pathv1}/peerings?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getSubscriptionDatabaseByID(subscriptionId, databaseId, callback)</td>
    <td style="padding:15px">Get database by id</td>
    <td style="padding:15px">{base_path}/{version}/subscriptions/{pathv1}/databases/{pathv2}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">updateDatabase(subscriptionId, databaseId, body, callback)</td>
    <td style="padding:15px">Update database</td>
    <td style="padding:15px">{base_path}/{version}/subscriptions/{pathv1}/databases/{pathv2}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteDatabaseById(subscriptionId, databaseId, callback)</td>
    <td style="padding:15px">Delete database</td>
    <td style="padding:15px">{base_path}/{version}/subscriptions/{pathv1}/databases/{pathv2}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">updateCrdbLocalProperties(subscriptionId, databaseId, body, callback)</td>
    <td style="padding:15px">Update active-active regions</td>
    <td style="padding:15px">{base_path}/{version}/subscriptions/{pathv1}/databases/{pathv2}/regions?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getSubscriptionDatabases(subscriptionId, offset, limit, callback)</td>
    <td style="padding:15px">Get databases</td>
    <td style="padding:15px">{base_path}/{version}/subscriptions/{pathv1}/databases?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">createDatabase(subscriptionId, body, callback)</td>
    <td style="padding:15px">Create database</td>
    <td style="padding:15px">{base_path}/{version}/subscriptions/{pathv1}/databases?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">importDatabase(subscriptionId, databaseId, body, callback)</td>
    <td style="padding:15px">Import database</td>
    <td style="padding:15px">{base_path}/{version}/subscriptions/{pathv1}/databases/{pathv2}/import?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">backupDatabase(subscriptionId, databaseId, body, callback)</td>
    <td style="padding:15px">Backup database</td>
    <td style="padding:15px">{base_path}/{version}/subscriptions/{pathv1}/databases/{pathv2}/backup?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getSubscriptionById1(subscriptionId, callback)</td>
    <td style="padding:15px">Get fixed subscription by id</td>
    <td style="padding:15px">{base_path}/{version}/fixed/subscriptions/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">updateSubscription1(subscriptionId, body, callback)</td>
    <td style="padding:15px">Update fixed subscription</td>
    <td style="padding:15px">{base_path}/{version}/fixed/subscriptions/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteSubscriptionById1(subscriptionId, callback)</td>
    <td style="padding:15px">Delete fixed subscription</td>
    <td style="padding:15px">{base_path}/{version}/fixed/subscriptions/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getAllSubscriptions1(callback)</td>
    <td style="padding:15px">Get fixed subscriptions</td>
    <td style="padding:15px">{base_path}/{version}/fixed/subscriptions?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">createSubscription1(body, callback)</td>
    <td style="padding:15px">Create fixed subscription</td>
    <td style="padding:15px">{base_path}/{version}/fixed/subscriptions?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getAllFixedSubscriptionsPlans(provider, callback)</td>
    <td style="padding:15px">Get Plans</td>
    <td style="padding:15px">{base_path}/{version}/fixed/plans?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getFixedSubscriptionsPlanById(planId, callback)</td>
    <td style="padding:15px">Get fixed subscription plan by id</td>
    <td style="padding:15px">{base_path}/{version}/fixed/plans/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getSubscriptionDatabaseByID1(subscriptionId, databaseId, callback)</td>
    <td style="padding:15px">Get fixed database by id</td>
    <td style="padding:15px">{base_path}/{version}/fixed/subscriptions/{pathv1}/databases/{pathv2}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteFixedDatabaseByID(subscriptionId, databaseId, body, callback)</td>
    <td style="padding:15px">Update fixed database</td>
    <td style="padding:15px">{base_path}/{version}/fixed/subscriptions/{pathv1}/databases/{pathv2}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteFixedDatabaseByID1(subscriptionId, databaseId, callback)</td>
    <td style="padding:15px">Delete fixed database</td>
    <td style="padding:15px">{base_path}/{version}/fixed/subscriptions/{pathv1}/databases/{pathv2}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getFixedSubscriptionDatabases(subscriptionId, offset, limit, callback)</td>
    <td style="padding:15px">Get fixed databases</td>
    <td style="padding:15px">{base_path}/{version}/fixed/subscriptions/{pathv1}/databases?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">createFixedDatabase(subscriptionId, body, callback)</td>
    <td style="padding:15px">Create fixed database</td>
    <td style="padding:15px">{base_path}/{version}/fixed/subscriptions/{pathv1}/databases?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">importDatabase1(subscriptionId, databaseId, body, callback)</td>
    <td style="padding:15px">Import fixed database</td>
    <td style="padding:15px">{base_path}/{version}/fixed/subscriptions/{pathv1}/databases/{pathv2}/import?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">backupDatabase1(subscriptionId, databaseId, callback)</td>
    <td style="padding:15px">Backup fixed database</td>
    <td style="padding:15px">{base_path}/{version}/fixed/subscriptions/{pathv1}/databases/{pathv2}/backup?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getCloudAccountById(cloudAccountId, callback)</td>
    <td style="padding:15px">Get cloud account by id</td>
    <td style="padding:15px">{base_path}/{version}/cloud-accounts/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">updateCloudAccount(cloudAccountId, body, callback)</td>
    <td style="padding:15px">Update cloud account</td>
    <td style="padding:15px">{base_path}/{version}/cloud-accounts/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteCloudAccount(cloudAccountId, callback)</td>
    <td style="padding:15px">Delete cloud account</td>
    <td style="padding:15px">{base_path}/{version}/cloud-accounts/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getCloudAccounts(callback)</td>
    <td style="padding:15px">Get cloud accounts</td>
    <td style="padding:15px">{base_path}/{version}/cloud-accounts?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">createCloudAccount(body, callback)</td>
    <td style="padding:15px">Create cloud account</td>
    <td style="padding:15px">{base_path}/{version}/cloud-accounts?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getUserByID(aclUserId, callback)</td>
    <td style="padding:15px">Get ACL user by id</td>
    <td style="padding:15px">{base_path}/{version}/acl/users/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">updateUser1(aclUserId, body, callback)</td>
    <td style="padding:15px">Update ACL user</td>
    <td style="padding:15px">{base_path}/{version}/acl/users/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteUser(aclUserId, callback)</td>
    <td style="padding:15px">Delete ACL user</td>
    <td style="padding:15px">{base_path}/{version}/acl/users/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">updateRole(aclRoleId, body, callback)</td>
    <td style="padding:15px">Update ACL role</td>
    <td style="padding:15px">{base_path}/{version}/acl/roles/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteAclRole(aclRoleId, callback)</td>
    <td style="padding:15px">Delete ACL role</td>
    <td style="padding:15px">{base_path}/{version}/acl/roles/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">updateRedisRule(aclRedisRuleId, body, callback)</td>
    <td style="padding:15px">Update ACL redis rule</td>
    <td style="padding:15px">{base_path}/{version}/acl/redisRules/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteRedisRule(aclRedisRuleId, callback)</td>
    <td style="padding:15px">Delete ACL redis rule</td>
    <td style="padding:15px">{base_path}/{version}/acl/redisRules/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getAllUsers1(callback)</td>
    <td style="padding:15px">Get ACL users</td>
    <td style="padding:15px">{base_path}/{version}/acl/users?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">createUser(body, callback)</td>
    <td style="padding:15px">Create ACL user</td>
    <td style="padding:15px">{base_path}/{version}/acl/users?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getRoles(callback)</td>
    <td style="padding:15px">Get ACL roles</td>
    <td style="padding:15px">{base_path}/{version}/acl/roles?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">createRole(body, callback)</td>
    <td style="padding:15px">Create ACL role</td>
    <td style="padding:15px">{base_path}/{version}/acl/roles?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getAllRedisRules(callback)</td>
    <td style="padding:15px">Get ACL redis rules</td>
    <td style="padding:15px">{base_path}/{version}/acl/redisRules?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">createRedisRule(body, callback)</td>
    <td style="padding:15px">Create ACL redis rule</td>
    <td style="padding:15px">{base_path}/{version}/acl/redisRules?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getAllTasks(callback)</td>
    <td style="padding:15px">Get tasks</td>
    <td style="padding:15px">{base_path}/{version}/tasks?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getTaskById(taskId, callback)</td>
    <td style="padding:15px">Get task by id</td>
    <td style="padding:15px">{base_path}/{version}/tasks/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getSupportedRegions(provider, callback)</td>
    <td style="padding:15px">Get flexible plans regions</td>
    <td style="padding:15px">{base_path}/{version}/regions?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getAccountPaymentMethods(callback)</td>
    <td style="padding:15px">Get payment methods</td>
    <td style="padding:15px">{base_path}/{version}/payment-methods?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getAccountSystemLogs(offset, limit, callback)</td>
    <td style="padding:15px">Get system log</td>
    <td style="padding:15px">{base_path}/{version}/logs?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getSupportedDatabaseModules(callback)</td>
    <td style="padding:15px">Get modules</td>
    <td style="padding:15px">{base_path}/{version}/database-modules?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getDataPersistenceOptions(callback)</td>
    <td style="padding:15px">Get list of data persistence options</td>
    <td style="padding:15px">{base_path}/{version}/data-persistence?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">get(callback)</td>
    <td style="padding:15px">Get current Account</td>
    <td style="padding:15px">{base_path}/{version}/?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
</table>
<br>
